@@ -1,3 +1,4 @@
+#' @importFrom S4Vectors isSingleString
 .sce_validity <- function(object) {
     msg <- NULL
 
@@ -8,7 +9,13 @@
         msg <- c(msg, "'nrow' of 'int_colData' not equal to 'ncol(object)'")
     }
 
-    if (objectVersion(object) >= "1.7.1") {
+    obj.ver <- objectVersion(object)
+    if (length(obj.ver) != 1 || !is(obj.ver, "numeric_version")) {
+        msg <- c(msg, "'objectVersion' should return a single version value")
+        return(msg) # no point checking the rest if this doesn't hold.
+    }
+
+    if (obj.ver >= "1.7.1") {
         if (!.red_key %in% colnames(int_colData(object))) {
             msg <- c(msg, "no 'reducedDims' field in 'int_colData'")
         }
@@ -17,7 +24,7 @@
         }
     }
 
-    if (objectVersion(object) >= "1.11.3") {
+    if (obj.ver >= "1.11.3") {
         if (!.rowp_key %in% colnames(int_elementMetadata(object))) {
             msg <- c(msg, "no 'rowPairs' field in 'int_elementMetadata'")
         }
@@ -26,6 +33,11 @@
         }
     }
 
+    main.name <- int_metadata(object)$mainExpName
+    if (!is.null(main.name) && !isSingleString(main.name)) {
+        msg <- c(msg, "'mainExpName' should return NULL or a single non-NA string")
+    }
+
     if (length(msg)) { return(msg) }
     return(TRUE)
 }
